@@ -241,7 +241,7 @@ lmCombine <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteForce=FALSE, s
     ourTerms <- testModel$terms;
 
     finalModel <- list(coefficients=parametersCombined, residuals=as.vector(errors), fitted.values=as.vector(yFitted),
-                       df.residual=df, coefficientsSE=parametersSECombined, importance=importance,
+                       df.residual=df, se=parametersSECombined, importance=importance,
                        IC=ICValue, call=testModel$call, logLik=logLikCombined, rank=nVariables+1,
                        model=ourData, terms=ourTerms, qr=qr(ourData), df=sum(importance)+1);
 
