@@ -25,7 +25,7 @@
 #' @return Function returns \code{model} - the final model of the class "lm".
 #'
 #' @seealso \code{\link[stats]{step}, \link[greybox]{xregExpander},
-#' \link[greybox]{combiner}}
+#' \link[greybox]{combine}}
 #'
 #' @examples
 #'
@@ -39,13 +39,13 @@
 #' xreg <- matrix(rnorm(20000,10,3),100,200)
 #' xreg <- cbind(100+0.5*xreg[,1]-0.75*xreg[,2]+rnorm(100,0,3),xreg,rnorm(100,300,10))
 #' colnames(xreg) <- c("y",paste0("x",c(1:200)),"Noise")
-#' ourModel <- stepwise(xreg,ic="AICc",method="s")
+#' ourModel <- stepwise(xreg,ic="AICc")
 #' plot(ourModel$ICs,type="l",ylim=range(min(ourModel$ICs),max(ourModel$ICs)+5))
 #' points(ourModel$ICs)
 #' text(c(1:length(ourModel$ICs))+0.1,ourModel$ICs+5,names(ourModel$ICs))
 #'
 #' @export stepwise
-stepwise <- function(data, ic=c("AICc","AIC","BIC"), silent=TRUE, df=NULL,
+stepwise <- function(data, ic=c("AICc","AIC","BIC","BICc"), silent=TRUE, df=NULL,
                      method=c("pearson","kendall","spearman")){
 ##### Function that selects variables based on IC and using partial correlations
     ourData <- data;
@@ -68,6 +68,9 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC"), silent=TRUE, df=NULL,
     else if(ic=="BIC"){
         IC <- BIC;
     }
+    else if(ic=="BICc"){
+        IC <- BICc;
+    }
 
     method <- method[1];
 
@@ -79,7 +82,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC"), silent=TRUE, df=NULL,
     testModel <- lm(as.formula(testFormula),data=ourData);
     # Write down the logLik and take df into account
     logLikValue <- logLik(testModel);
-    attributes(logLikValue)$df <- attributes(logLikValue)$df + df;
+    attributes(logLikValue)$df <- nParam(logLikValue) + df;
     # Write down the IC. This one needs to be calculated from the logLik
     # in order to take the additional df into account.
     currentIC <- bestIC <- IC(logLikValue);
@@ -114,7 +117,7 @@ stepwise <- function(data, ic=c("AICc","AIC","BIC"), silent=TRUE, df=NULL,
         testModel <- lm(as.formula(testFormula),data=ourData);
         # Modify logLik
         logLikValue <- logLik(testModel);
-        attributes(logLikValue)$df <- attributes(logLikValue)$df + df;
+        attributes(logLikValue)$df <- nParam(logLikValue) + df;
         if(attributes(logLikValue)$df >= (obs+1)){
             if(!silent){
                 warning("Number of degrees of freedom is greater than number of observations. Cannot proceed.");
